@@ -1,4 +1,4 @@
-require 'chef_zero/data_store/interface_v1'
+require "chef_zero/data_store/interface_v1"
 
 module ChefZero
   module DataStore
