@@ -20,8 +20,19 @@ module ChefZero
         if !acl_path
           raise RestErrorResponse.new(404, "Object not found: #{build_uri(request.base_uri, request.rest_path)}")
         end
-        acls = FFI_Yajl::Parser.parse(get_data(request, acl_path), :create_additions => false)
+        acls = FFI_Yajl::Parser.parse(get_data(request, acl_path))
         acls = ChefData::DataNormalizer.normalize_acls(acls)
+        if request.query_params["detail"] == "granular"
+          acls.each do |perm, ace|
+            acls[perm]["actors"] = []
+          end
+        else
+          acls.each do |perm, ace|
+            acls[perm].delete("clients")
+            acls[perm].delete("users")
+          end
+        end
+
         json_response(200, acls)
       end
     end
