@@ -22,13 +22,13 @@ module ChefZero
 
         # Honor frozen
         if existing_cookbook
-          existing_cookbook_json = FFI_Yajl::Parser.parse(existing_cookbook, :create_additions => false)
+          existing_cookbook_json = FFI_Yajl::Parser.parse(existing_cookbook)
           if existing_cookbook_json["frozen?"]
             if request.query_params["force"] != "true"
               raise RestErrorResponse.new(409, "The cookbook #{name} at version #{version} is frozen. Use the 'force' option to override.")
             end
             # For some reason, you are forever unable to modify "frozen?" on a frozen cookbook.
-            request_body = FFI_Yajl::Parser.parse(request.body, :create_additions => false)
+            request_body = FFI_Yajl::Parser.parse(request.body)
             if !request_body["frozen?"]
               request_body["frozen?"] = true
               request.body = FFI_Yajl::Encoder.encode(request_body, :pretty => true)
@@ -71,7 +71,7 @@ module ChefZero
 
       def get_checksums(cookbook)
         result = []
-        FFI_Yajl::Parser.parse(cookbook, :create_additions => false).each_pair do |key, value|
+        FFI_Yajl::Parser.parse(cookbook).each_pair do |key, value|
           if value.is_a?(Array)
             value.each do |file|
               if file.is_a?(Hash) && file.has_key?("checksum")
@@ -118,7 +118,7 @@ module ChefZero
 
       def populate_defaults(request, response_json)
         # Inject URIs into each cookbook file
-        cookbook = FFI_Yajl::Parser.parse(response_json, :create_additions => false)
+        cookbook = FFI_Yajl::Parser.parse(response_json)
         cookbook = ChefData::DataNormalizer.normalize_cookbook(self, request.rest_path[0..1], cookbook, request.rest_path[3], request.rest_path[4], request.base_uri, request.method)
         FFI_Yajl::Encoder.encode(cookbook, :pretty => true)
       end
