@@ -1,14 +1,14 @@
-require 'chef_zero/endpoints/cookbooks_base'
+require "chef_zero/endpoints/cookbooks_base"
 
 module ChefZero
   module Endpoints
     # /cookbooks
     class CookbooksEndpoint < CookbooksBase
       def get(request)
-        if request.query_params['num_versions'] == 'all'
+        if request.query_params["num_versions"] == "all"
           num_versions = nil
-        elsif request.query_params['num_versions']
-          num_versions = request.query_params['num_versions'].to_i
+        elsif request.query_params["num_versions"]
+          num_versions = request.query_params["num_versions"].to_i
         else
           num_versions = 1
         end
