@@ -16,7 +16,7 @@ module ChefZero
       end
 
       def self.populate_defaults(request, response_json, data_bag, data_bag_item)
-        response = FFI_Yajl::Parser.parse(response_json, :create_additions => false)
+        response = FFI_Yajl::Parser.parse(response_json)
         response = ChefData::DataNormalizer.normalize_data_bag_item(response, data_bag, data_bag_item, request.method)
         FFI_Yajl::Encoder.encode(response, :pretty => true)
       end
