@@ -7,7 +7,7 @@ module ChefZero
     class DataBagsEndpoint < RestListEndpoint
       def post(request)
         contents = request.body
-        json = FFI_Yajl::Parser.parse(contents, :create_additions => false)
+        json = FFI_Yajl::Parser.parse(contents)
         name = identity_keys.map { |k| json[k] }.select { |v| v }.first
         if name.nil?
           error(400, "Must specify #{identity_keys.map { |k| k.inspect }.join(' or ')} in JSON")
