@@ -6,7 +6,7 @@ module ChefZero
     # /environments/NAME/cookbooks
     class EnvironmentCookbooksEndpoint < CookbooksBase
       def get(request)
-        environment = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..3]), :create_additions => false)
+        environment = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..3]))
         constraints = environment["cookbook_versions"] || {}
         if request.query_params["num_versions"] == "all"
           num_versions = nil
