@@ -24,7 +24,7 @@ module ChefZero
       end
 
       def populate_defaults(request, response_json)
-        response = FFI_Yajl::Parser.parse(response_json, :create_additions => false)
+        response = FFI_Yajl::Parser.parse(response_json)
         response = ChefData::DataNormalizer.normalize_environment(response, request.rest_path[3])
         FFI_Yajl::Encoder.encode(response, :pretty => true)
       end
