@@ -11,7 +11,7 @@ module ChefZero
       end
 
       def populate_defaults(request, response_json)
-        group = FFI_Yajl::Parser.parse(response_json, :create_additions => false)
+        group = FFI_Yajl::Parser.parse(response_json)
         group = ChefData::DataNormalizer.normalize_group(group, request.rest_path[3], request.rest_path[1])
         FFI_Yajl::Encoder.encode(group, :pretty => true)
       end
