@@ -21,7 +21,7 @@ module ChefZero
       end
 
       def populate_defaults(request, response_json)
-        node = FFI_Yajl::Parser.parse(response_json, :create_additions => false)
+        node = FFI_Yajl::Parser.parse(response_json)
         node = ChefData::DataNormalizer.normalize_node(node, request.rest_path[3])
         FFI_Yajl::Encoder.encode(node, :pretty => true)
       end
