@@ -13,7 +13,7 @@ module ChefZero
         end
         username = $1
         path = request.rest_path[0..-2] + [username]
-        data = FFI_Yajl::Parser.parse(get_data(request, path), :create_additions => false)
+        data = FFI_Yajl::Parser.parse(get_data(request, path))
         delete_data(request, path)
         json_response(200, { "id" => id, "username" => username })
       end
