@@ -9,7 +9,7 @@ module ChefZero
       def post(request)
         org_name = request.rest_path[-2]
         validator_path = [ "organizations", org_name, "clients", "#{org_name}-validator"]
-        validator = FFI_Yajl::Parser.parse(get_data(request, validator_path), :create_additions => false)
+        validator = FFI_Yajl::Parser.parse(get_data(request, validator_path))
         private_key, public_key = server.gen_key_pair
         validator["public_key"] = public_key
         set_data(request, validator_path, FFI_Yajl::Encoder.encode(validator, :pretty => true))
