@@ -6,7 +6,7 @@ module ChefZero
     # /system_recovery
     class SystemRecoveryEndpoint < RestBase
       def post(request)
-        request_json = FFI_Yajl::Parser.parse(request.body, :create_additions => false)
+        request_json = FFI_Yajl::Parser.parse(request.body)
         name = request_json["username"]
         password = request_json["password"]
         user = get_data(request, request.rest_path[0..-2] + ["users", name], :nil)
@@ -14,7 +14,7 @@ module ChefZero
           raise RestErrorResponse.new(403, "Nonexistent user")
         end
 
-        user = FFI_Yajl::Parser.parse(user, :create_additions => false)
+        user = FFI_Yajl::Parser.parse(user)
         user = ChefData::DataNormalizer.normalize_user(user, name, [ "username" ], server.options[:osc_compat])
         if !user["recovery_authentication_enabled"]
           raise RestErrorResponse.new(403, "Only users with recovery_authentication_enabled=true may use /system_recovery to log in")
